fix_ffmpeg {#yarp_3_5}
----------

### Port Monitors

#### `image_compression_ffmpeg`

* Fixed symbol lookup runtime error.


### Devices

#### `ffmpeg_grabber`

* Fixed symbol lookup runtime error.

#### `ffmpeg_writer`

* Fixed symbol lookup runtime error.
